@@ -1,4 +1,4 @@
-#  Copyright (C) 2002  Stanislav Sinyagin
+#  Copyright (C) 2002-2011  Stanislav Sinyagin
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -14,25 +14,27 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 
-# $Id$
 # Stanislav Sinyagin <ssinyagin@yahoo.com>
 
 
 package Torrus::Collector;
-@Torrus::Collector::ISA = qw(Torrus::Scheduler::PeriodicTask);
-
 use strict;
+use warnings;
+
+use base 'Torrus::Scheduler::PeriodicTask';
+
 use Torrus::ConfigTree;
 use Torrus::Log;
 use Torrus::RPN;
-use Torrus::Scheduler;
 
 BEGIN
 {
     foreach my $mod ( @Torrus::Collector::loadModules )
     {
-        eval( 'require ' . $mod );
-        die( $@ ) if $@;
+        if( not eval('require ' . $mod) or $@ )
+        {
+            die($@);
+        }
     }
 }
 
@@ -46,6 +48,7 @@ sub initThreads
             &{$Torrus::Collector::initThreadsHandlers{$key}}();
         }
     }
+    return;
 }
 
 
@@ -193,8 +196,9 @@ sub addTarget
             my $storage_string = $storage_type . '-storage';
             if( ref( $Torrus::Collector::initTarget{$storage_string} ) )
             {
-                &{$Torrus::Collector::initTarget{$storage_string}}($self,
-                                                                   $token);
+                $ok =
+                    &{$Torrus::Collector::initTarget{
+                        $storage_string}}($self, $token) ? $ok:0;
             }
         }
     }
@@ -203,6 +207,7 @@ sub addTarget
     {
         $self->deleteTarget( $token );
     }
+    return;
 }
 
 
@@ -270,6 +275,7 @@ sub fetchParams
         }
         @maps = @next_maps;
     }
+    return;
 }
 
 
@@ -292,6 +298,7 @@ sub fetchMoreParams
             $$ref->{$param} = $value;
         }
     }
+    return;
 }
 
 
@@ -304,6 +311,37 @@ sub param
     return $self->{'targets'}{$token}{'params'}{$param};
 }
 
+# The following 3 methods get around undefined parameters and
+# make "use warnings" happy
+
+sub paramEnabled
+{
+    my $self = shift;
+    my $token = shift;
+    my $param = shift;
+    my $val = $self->param($token, $param);
+    return (defined($val) and ($val eq 'yes'));
+}
+
+sub paramDisabled
+{
+    my $self = shift;
+    my $token = shift;
+    my $param = shift;
+    my $val = $self->param($token, $param);
+    return (not defined($val) or ($val ne 'yes'));
+}
+
+sub paramString
+{
+    my $self = shift;
+    my $token = shift;
+    my $param = shift;
+    my $val = $self->param($token, $param);
+    return (defined($val) ? $val:'');    
+}
+
+
 sub setParam
 {
     my $self = shift;
@@ -312,6 +350,7 @@ sub setParam
     my $value = shift;
 
     $self->{'targets'}{$token}{'params'}{$param} = $value;
+    return;
 }
 
 
@@ -352,6 +391,7 @@ sub registerDeleteCallback
         $self->{'targets'}{$token}{'deleteProc'} = [];
     }
     push( @{$self->{'targets'}{$token}{'deleteProc'}}, $proc );
+    return;
 }
 
 sub deleteTarget
@@ -371,6 +411,7 @@ sub deleteTarget
         }
     }
     delete $self->{'targets'}{$token};
+    return;
 }
 
 # Returns a reference to token-specific local data
@@ -409,8 +450,6 @@ sub run
 {
     my $self = shift;
 
-    undef $self->{'values'};
-    
     foreach my $collector_type ( @{$self->{'types_sorted'}} )
     {
         next unless $self->{'types_in_use'}{$collector_type};
@@ -430,7 +469,7 @@ sub run
         
         if( defined( $self->{'config_tree'} ) )
         {
-            undef $self->{'config_tree'};
+            delete $self->{'config_tree'};
         }
     }
 
@@ -452,7 +491,7 @@ sub run
 
         if( defined( $self->{'config_tree'} ) )
         {
-            undef $self->{'config_tree'};
+            delete $self->{'config_tree'};
         }        
     }
     
@@ -476,10 +515,11 @@ sub run
 
             if( defined( $self->{'config_tree'} ) )
             {
-                undef $self->{'config_tree'};
+                delete $self->{'config_tree'};
             }
         }
     }
+    return;
 }
 
 
@@ -500,10 +540,10 @@ sub setValue
             # Screen out the percent sign and $_
             $code =~ s/DOLLAR/\$/gm;
             $code =~ s/MOD/\%/gm;
-            Debug('Value before transformation: ' . $value);
+            Debug('Value before transformation: ' . $value);            
             $_ = $value;
-            $value = do { eval $code };
-            if( $@ )
+            $value = eval($code);
+            if( not defined($value) or $@ )
             {
                 Error('Fatal error in transformation code: ' . $@ );
                 $value = 'U';
@@ -561,6 +601,7 @@ sub setValue
                                                         $value, $timestamp,
                                                         $uptime );
     }
+    return;
 }
 
 
@@ -580,145 +621,6 @@ sub configTree
 }
 
 
-#######  Collector scheduler  ########
-
-package Torrus::CollectorScheduler;
-@Torrus::CollectorScheduler::ISA = qw(Torrus::Scheduler);
-
-use Torrus::ConfigTree;
-use Torrus::Log;
-use Torrus::Scheduler;
-use Torrus::TimeStamp;
-
-
-sub beforeRun
-{
-    my $self = shift;
-
-    &Torrus::DB::checkInterrupted();
-
-    my $tree = $self->treeName();
-    my $config_tree = new Torrus::ConfigTree(-TreeName => $tree, -Wait => 1);
-    if( not defined( $config_tree ) )
-    {
-        return undef;
-    }
-
-    my $data = $self->data();
-
-    my $instance = $self->{'options'}{'-Instance'};
-        
-    # Prepare the list of tokens, sorted by period and offset,
-    # from config tree or from cache.
-
-    my $need_new_tasks = 0;
-
-    Torrus::TimeStamp::init();
-    my $timestamp_key = $tree . ':' . $instance . ':collector_cache';
-    my $known_ts = Torrus::TimeStamp::get( $timestamp_key );
-    my $actual_ts = $config_tree->getTimestamp();
-    
-    if( $actual_ts >= $known_ts or not $data->{'targets_initialized'} )
-    {
-        my $db_lock;
-        my $cursor_lock;
-        if( $Torrus::Collector::exclusiveStartupLock )
-        {
-            Info('Acquiring an exclusive lock for configuration slurp');
-            $db_lock =
-                new Torrus::DB( 'collector_lock', -WriteAccess => 1 );        
-            $cursor_lock = $db_lock->cursor( -Write => 1 );
-        }
-        
-        Info('Initializing tasks for collector instance ' . $instance);
-        Debug("Config TS: $actual_ts, Collector TS: $known_ts");
-        my $init_start = time();
-
-        my $targets = {};
-
-        my $db_tokens =
-            new Torrus::DB('collector_tokens' . '_' . $instance . '_' .
-                           $config_tree->{'ds_config_instance'},
-                           -Subdir => $tree);
-        
-        my $cursor = $db_tokens->cursor();
-        while( my ($token, $schedule) = $db_tokens->next($cursor) )
-        {
-            my ($period, $offset) = split(/:/o, $schedule);
-            if( not exists( $targets->{$period}{$offset} ) )
-            {
-                $targets->{$period}{$offset} = [];
-            }
-            push( @{$targets->{$period}{$offset}}, $token );
-
-            &Torrus::DB::checkInterrupted();
-        }
-        $db_tokens->c_close($cursor);
-        undef $cursor;
-        $db_tokens->closeNow();
-        undef $db_tokens;
-        
-        &Torrus::DB::checkInterrupted();
-
-        # Set the timestamp
-        &Torrus::TimeStamp::setNow( $timestamp_key );
-        
-        $self->flushTasks();
-
-        foreach my $period ( keys %{$targets} )
-        {
-            foreach my $offset ( keys %{$targets->{$period}} )
-            {
-                my $collector =
-                    new Torrus::Collector( -Period => $period,
-                                           -Offset => $offset,
-                                           -TreeName => $tree,
-                                           -Instance => $instance );
-
-                foreach my $token ( @{$targets->{$period}{$offset}} )
-                {
-                    &Torrus::DB::checkInterrupted();
-                    $collector->addTarget( $config_tree, $token );
-                }
-
-                $self->addTask( $collector );
-            }
-        }
-
-        if( $Torrus::Collector::exclusiveStartupLock )
-        {
-            $db_lock->c_close($cursor_lock);
-            undef $cursor_lock;
-            $db_lock->closeNow();
-            undef $db_lock;
-        }
-
-        Verbose(sprintf("Tasks initialization finished in %d seconds",
-                        time() - $init_start));
-
-        $data->{'targets_initialized'} = 1;        
-        Info('Tasks for collector instance ' . $instance . ' initialized');
-
-        foreach my $collector_type ( keys %Torrus::Collector::collectorTypes )
-        {
-            if( ref($Torrus::Collector::initCollectorGlobals{
-                $collector_type}) )
-            {
-                &{$Torrus::Collector::initCollectorGlobals{
-                    $collector_type}}($tree, $instance);
-                
-                Verbose('Initialized collector globals for type: ' .
-                        $collector_type);
-            }
-        }
-    }
-    
-    Torrus::TimeStamp::release();
-    
-    return 1;
-}
-
-
 1;
 
 
