@@ -15,7 +15,6 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-# $Id$
 # Christian Schnidrig <christian.schnidrig@bluewin.ch>
 
 
@@ -24,6 +23,7 @@
 package Torrus::Collector::CDef_Params;
 
 use strict;
+use warnings;
 
 ###  Initialize the configuration validator with module-specific parameters
 our %params =
@@ -39,6 +39,7 @@ sub initValidatorLeafParams
     my $hashref = shift;
     $hashref->{'ds-type'}{'collector'}{'collector-type'}{'cdef'} =
         \%params;
+    return;
 }
 
 
@@ -61,6 +62,7 @@ sub initAdmInfo
     {
         $categories->{$pname} = $category;
     }
+    return;
 }
 
 
