@@ -14,7 +14,6 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 
-# $Id$
 # Stanislav Sinyagin <ssinyagin@yahoo.com>
 
 ## Pluggable backend module for ExternalStorage
@@ -26,6 +25,8 @@
 package Torrus::Collector::ExtDBI;
 
 use strict;
+use warnings;
+
 use DBI;
 use Date::Format;
 
@@ -55,6 +56,7 @@ sub backendInit
 {
     my $collector = shift;
     my $token = shift;
+    return;
 }
 
 sub backendOpenSession
@@ -69,6 +71,7 @@ sub backendOpenSession
             Error('Error preparing the SQL statement: ' . $dbh->errstr);
         }
     }
+    return;
 }
 
 
@@ -114,6 +117,7 @@ sub backendCloseSession
         $dbh->disconnect();
         undef $dbh;
     }
+    return;
 }
 
 
