@@ -50,6 +50,7 @@ $Torrus::Collector::params{'snmp'} = {
     'snmp-port'         => undef,
     'snmp-community'    => undef,
     'snmp-username'     => undef,
+    'snmp-contextname'  => undef,
     'snmp-authkey'      => undef,
     'snmp-authpassword' => undef,
     'snmp-authprotocol' => 'md5',
@@ -386,6 +387,13 @@ sub openBlockingSession
         {
             $session->max_msg_size( $maxmsgsize );
         }
+
+        my $contextname = $collector->param($token, 'snmp-contextname');
+        if( defined($contextname) and $contextname ne '' )
+        {
+            # dirty hack: this is a private method in Net::SNMP
+            $session->_context_name($contextname);
+        }
     }
     
     return $session;
@@ -438,8 +446,14 @@ sub openNonblockingSession
     my $maxmsgsize = $collector->param($token, 'snmp-max-msg-size');
     if( defined( $maxmsgsize ) and $maxmsgsize > 0 )
     {
-        $session->max_msg_size( $maxmsgsize );
-        
+        $session->max_msg_size( $maxmsgsize );        
+    }
+
+    my $contextname = $collector->param($token, 'snmp-contextname');
+    if( defined($contextname) and $contextname ne '' )
+    {
+        # dirty hack: this is a private method in Net::SNMP
+        $session->_context_name($contextname);
     }
     
     return $session;
