@@ -738,7 +738,8 @@ sub validateMonitors
                 foreach my $when ( split(',', $launch_when) )
                 {
                     my $matched = 0;
-                    foreach my $event ('set', 'repeat', 'clear', 'forget')
+                    foreach my $event ('set', 'repeat', 'escalate',
+                                       'clear', 'clear_escalation', 'forget')
                     {
                         if( $when eq $event )
                         {
@@ -747,16 +748,8 @@ sub validateMonitors
                     }
                     if( not $matched )
                     {
-                        if( $when eq 'throw' )
-                        {
-                            Error('Event type "throw" is no longer ' .
-                                  'supported. Replace with "set".');
-                        }
-                        else
-                        {
-                            Error("Invalid value in parameter launch-when " .
-                                  "in action $action: $when");
-                        }
+                        Error("Invalid value in parameter launch-when " .
+                              "in action $action: $when");
                         $ok = 0;
                     }
                 }
@@ -803,6 +796,7 @@ sub validateMonitors
     {
         $ok = validateInstanceParams($config_tree, $monitor,
                                      'monitor', \%monitor_params) ? $ok:0;
+        
         my $alist = $config_tree->getParam( $monitor, 'action' );
         foreach my $action ( split(',', $alist ) )
         {
@@ -812,7 +806,29 @@ sub validateMonitors
                 $ok = 0;
             }
         }
+
+        my $esc = $config_tree->getParam($monitor, 'escalations');
+        if( defined($esc) )
+        {
+            my @escalation_times = split(',', $esc);
+            if( scalar(@escalation_times) == 0 )
+            {
+                Error("\"escalations\" is empty in $monitor");
+                $ok = 0;
+            }
+            
+            foreach my $esc_time (@escalation_times)
+            {
+                if( $esc_time !~ /^\d+$/ or $esc_time == 0 )
+                {
+                    Error("$esc_time is not a positive integer in " .
+                          "\"escalations\" in $monitor");
+                    $ok = 0;
+                }
+            }
+        }
     }
+    
     return $ok;
 }
 
