@@ -96,6 +96,7 @@ our @copyParams =
       'snmp-community',
       'snmp-version',
       'snmp-username',
+      'snmp-contextname',
       'snmp-authkey',
       'snmp-authpassword',
       'snmp-authprotocol',
@@ -223,8 +224,9 @@ sub discover
     }
     elsif( $version eq '3' )        
     {
-        foreach my $arg ( qw(-username -authkey -authpassword -authprotocol
-                             -privkey -privpassword -privprotocol) )
+        foreach my $arg ( qw(-username -authkey -authpassword
+                             -authprotocol -privkey
+                             -privpassword -privprotocol) )
         {
             if( defined $devdetails->param( 'snmp' . $arg ) )
             {
@@ -267,6 +269,13 @@ sub discover
         Error('Cannot create SNMP session: ' . $error);
         return undef;
     }
+
+    my $contextname = $devdetails->param('snmp-contextname');
+    if( defined($contextname) and $contextname ne '' )
+    {
+        # dirty hack: this is a private method in Net::SNMP
+        $session->_context_name($contextname);
+    }
     
     my @oids = ();
     foreach my $var ( @systemOIDs )
@@ -530,6 +539,8 @@ sub buildConfig
             # we should call this anyway, in order to flush the overlays
             # set by previous host
             $cb->setRegistryOverlays( @registryOverlays );            
+
+            my $reachabilityStatsEnabled = 0;
             
             if( $devdetails->paramEnabled('disable-snmpcollector' ) )
             {
@@ -548,6 +559,7 @@ sub buildConfig
                     ) )
                 {
                     push( @{$data->{'templates'}}, '::snmp-reachability' );
+                    $reachabilityStatsEnabled = 1;
                 }
             }
 
@@ -570,6 +582,17 @@ sub buildConfig
                                            $data->{'param'},
                                            $data->{'templates'} );
 
+            if( $reachabilityStatsEnabled )
+            {
+                my $reachabilityMonitor =
+                    $devdetails->param('reachability-monitor');
+                if( defined($reachabilityMonitor) )
+                {
+                    $cb->addLeaf( $devNode, 'Device_Reachability',
+                                  {'monitor' => $reachabilityMonitor} );
+                }
+            }
+                    
             foreach my $alias
                 ( split( '\s*,\s*',
                          $devdetails->paramString('host-aliases') ) )
