@@ -21,6 +21,8 @@
 package Torrus::DevDiscover::ATMEL;
 
 use strict;
+use warnings;
+
 use Torrus::Log;
 
 
@@ -154,6 +156,7 @@ sub buildConfig
     {
         $cb->addTemplateApplication( $devNode, $tmpl );
     }
+    return;
 }
 
 
