@@ -17,7 +17,6 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 
-# $Id$
 # Jon Nistor <nistor at snickers dot org>
 #
 
@@ -25,6 +24,8 @@
 package Torrus::DevDiscover::Alteon;
 
 use strict;
+use warnings;
+
 use Torrus::Log;
 
 
@@ -157,7 +158,8 @@ sub buildConfig
                          { 'alteon-maint-index' => $mIndex },
                          [ 'Alteon::alteon-maint'] ); 
     }
-
+    
+    return;
 }
 
 1;
