@@ -48,15 +48,14 @@ our %oiddef =
 
      # CISCO-ENHANCED-MEMPOOL-MIB
      'cempMemPoolName'                   => '1.3.6.1.4.1.9.9.221.1.1.1.1.3',
+     'cempMemPoolHCUsed'                 => '1.3.6.1.4.1.9.9.221.1.1.1.1.18',
      
      # CISCO-MEMORY-POOL-MIB
      'ciscoMemoryPoolName'               => '1.3.6.1.4.1.9.9.48.1.1.1.2',
 
      # CISCO-PROCESS-MIB
-     'cpmCPUTotalTable'                  => '1.3.6.1.4.1.9.9.109.1.1.1.1',
      'cpmCPUTotalPhysicalIndex'          => '1.3.6.1.4.1.9.9.109.1.1.1.1.2',
      'cpmCPUTotal1minRev'                => '1.3.6.1.4.1.9.9.109.1.1.1.1.7',
-     'cpmCPUTotal1min'                   => '1.3.6.1.4.1.9.9.109.1.1.1.1.4',
 
      # OLD-CISCO-CPU-MIB
      'avgBusy1'                          => '1.3.6.1.4.1.9.2.1.57.0'
@@ -152,26 +151,21 @@ sub discover
     
     if( $devdetails->paramDisabled('CiscoGeneric::disable-memory-pools') )
     {
-        my $eMemPool =
-            $session->get_table( -baseoid =>
-                                 $dd->oiddef('cempMemPoolName') );
-        
-        if( defined($eMemPool) and scalar(keys %{$eMemPool}) > 0 and
+        my $eMemPool = $dd->walkSnmpTable('cempMemPoolName');
+        my $eMemHC = $dd->walkSnmpTable('cempMemPoolHCUsed');
+               
+        if( scalar(keys %{$eMemPool}) > 0 and
             $devdetails->isDevType('RFC2737_ENTITY_MIB') )
         {
-            $devdetails->storeSnmpVars( $eMemPool );
             $devdetails->setCap('cempMemPool');
             $data->{'cempMemPool'} = {};
 
-            foreach my $INDEX
-                ( $devdetails->
-                  getSnmpIndices($dd->oiddef('cempMemPoolName') ) )
+            foreach my $INDEX (keys %{$eMemPool})
             {
                 # $INDEX is a pair entPhysicalIndex . cempMemPoolIndex
                 my ( $phyIndex, $poolIndex ) = split('\.', $INDEX);
 
-                my $poolName = $devdetails->
-                    snmpVar($dd->oiddef('cempMemPoolName') . '.' . $INDEX );
+                my $poolName = $eMemPool->{$INDEX};
 
                 $poolName = 'Processor' unless $poolName;
                 
@@ -189,36 +183,32 @@ sub discover
                     'phyDescr' => $phyDescr,
                     'phyName'  => $phyName
                     };
+
+                if( defined($eMemHC->{$INDEX}) )
+                {
+                    $data->{'cempMemPool'}{$INDEX}{'hc'} = 1;
+                }
             }
         }
         else
         {
-            my $MemoryPool =
-                $session->get_table( -baseoid =>
-                                     $dd->oiddef('ciscoMemoryPoolName') );
+            my $MemoryPool = $dd->walkSnmpTable('ciscoMemoryPoolName');
 
-            if( defined($MemoryPool) and scalar(keys %{$MemoryPool}) > 0 )
+            if( scalar(keys %{$MemoryPool}) > 0 )
             {
-                $devdetails->storeSnmpVars( $MemoryPool );
                 $devdetails->setCap('ciscoMemoryPool');
                 
                 $data->{'ciscoMemoryPool'} = {};
                 
-                foreach my $memType
-                    ( $devdetails->
-                      getSnmpIndices($dd->oiddef('ciscoMemoryPoolName')) )
+                foreach my $memType (keys %{$MemoryPool})
                 {
                     # According to CISCO-MEMORY-POOL-MIB, only types 1 to 5
                     # are static, and the rest are dynamic
                     # (of which none ever seen)
                     if( $memType <= 5 )
                     {
-                        my $name =
-                            $devdetails->
-                            snmpVar($dd->oiddef('ciscoMemoryPoolName') .
-                                    '.' . $memType );
-
-                        $data->{'ciscoMemoryPool'}{$memType} = $name;
+                        $data->{'ciscoMemoryPool'}{$memType} =
+                            $MemoryPool->{$memType};
                     }
                 }
             }
@@ -227,37 +217,30 @@ sub discover
 
     if( $devdetails->paramDisabled('CiscoGeneric::disable-cpu-stats') )
     {
-        my $ciscoCpuStats =
-            $session->get_table( -baseoid => $dd->oiddef('cpmCPUTotalTable') );
-
-        if( defined $ciscoCpuStats )
+        my $cpmCPUTotalPhysicalIndex =
+            $dd->walkSnmpTable('cpmCPUTotalPhysicalIndex');
+        my $cpmCPUTotal1minRev =
+            $dd->walkSnmpTable('cpmCPUTotal1minRev');
+        
+        if( scalar(keys %{$cpmCPUTotalPhysicalIndex}) > 0 )
         {
             $devdetails->setCap('ciscoCpuStats');
-            $devdetails->storeSnmpVars( $ciscoCpuStats );
 
             $data->{'ciscoCpuStats'} = {};
 
             # Find multiple CPU entries pointing to the same Phy index
             my %phyReferers = ();            
-            foreach my $INDEX
-                ( $devdetails->
-                  getSnmpIndices($dd->oiddef('cpmCPUTotalPhysicalIndex') ) )
+            foreach my $INDEX (keys %{$cpmCPUTotalPhysicalIndex})
             {
-                my $phyIndex = $devdetails->
-                    snmpVar($dd->oiddef('cpmCPUTotalPhysicalIndex') .
-                            '.' . $INDEX );
+                my $phyIndex = $cpmCPUTotalPhysicalIndex->{$INDEX};
                 $phyReferers{$phyIndex}++;
             }
                 
-            foreach my $INDEX
-                ( $devdetails->
-                  getSnmpIndices($dd->oiddef('cpmCPUTotalPhysicalIndex') ) )
+            foreach my $INDEX (keys %{$cpmCPUTotalPhysicalIndex})
             {
                 $data->{'ciscoCpuStats'}{$INDEX} = {};
 
-                my $phyIndex = $devdetails->
-                    snmpVar($dd->oiddef('cpmCPUTotalPhysicalIndex') .
-                            '.' . $INDEX );
+                my $phyIndex = $cpmCPUTotalPhysicalIndex->{$INDEX};
                 
                 my $phyDescr;
                 my $phyName;
@@ -290,8 +273,7 @@ sub discover
                     'phy-referers' => $phyReferers{$phyIndex},
                     'cpu-nick'   => $cpuNick };
                 
-                if( $devdetails->hasOID( $dd->oiddef('cpmCPUTotal1minRev') .
-                                         '.' .  $INDEX ) )
+                if( defined($cpmCPUTotal1minRev->{$INDEX}) )
                 {
                     $data->{'ciscoCpuStats'}{$INDEX}{'stats-type'} = 'revised';
                 }
@@ -493,9 +475,17 @@ sub buildConfig
                 $param->{'precedence'} =
                     sprintf("%d", 1000 -
                             $pool->{'phyIndex'} * 100 - $pool->{'poolIndex'});
+
+                $param->{'entity-phy-name'} = $pool->{'phyName'};
+
+                my $template = 'CiscoGeneric::cisco-enh-mempool';
+                if( $pool->{'hc'} )
+                {
+                    $template = 'CiscoGeneric::cisco-enh-mempool-hc';
+                }
                 
                 $cb->addSubtree( $subtreeNode, $poolSubtreeName, $param,
-                                 [ 'CiscoGeneric::cisco-enh-mempool' ]);
+                                 [ $template ]);
             }
         }
         else
@@ -551,11 +541,14 @@ sub buildConfig
             {
                 $param->{'cisco-cpu-indexmap'} = $INDEX;
                 $param->{'cisco-cpu-ref'} = $INDEX;
+                $param->{'entity-phy-name'} =
+                    $cpu->{'phy-name'} . ' (' . $INDEX . ')';
             }
             else
             {
                 $param->{'entity-phy-index'} = $cpu->{'phy-index'};
                 $param->{'cisco-cpu-ref'} = '%entity-phy-index%';
+                $param->{'entity-phy-name'} = $cpu->{'phy-name'};
             }
             
             my @templates;
