@@ -27,7 +27,7 @@ use Torrus::Log;
 
 
 $Torrus::DevDiscover::registry{'CiscoIOS'} = {
-    'sequence'     => 500,
+    'sequence'     => 510,
     'checkdevtype' => \&checkdevtype,
     'discover'     => \&discover,
     'buildConfig'  => \&buildConfig
@@ -36,8 +36,6 @@ $Torrus::DevDiscover::registry{'CiscoIOS'} = {
 
 our %oiddef =
     (
-     # CISCO-SMI
-     'ciscoProducts'                     => '1.3.6.1.4.1.9.1',
      # CISCO-PRODUCTS-MIB
      'ciscoLS1010'                       => '1.3.6.1.4.1.9.1.107',
      # CISCO-IMAGE-MIB
@@ -162,27 +160,44 @@ sub checkdevtype
     my $dd = shift;
     my $devdetails = shift;
 
-    if( not $dd->oidBaseMatch
-        ( 'ciscoProducts',
-          $devdetails->snmpVar( $dd->oiddef('sysObjectID') ) ) )
+    if( not $devdetails->isDevType('CiscoGeneric') )
     {
         return 0;
     }
 
-    my $session = $dd->session();
-    if( not $dd->checkSnmpTable('ciscoImageTable') )
+    # first, try to find IOS or IOS XR in sysDescr
+    my $sysDescr = $devdetails->snmpVar($dd->oiddef('sysDescr'));
+    my $found = 0;
+    if( defined($sysDescr) and
+        index( $sysDescr, 'Cisco IOS Software' ) >= 0 )
     {
-        if( $dd->checkSnmpTable('ceImageTable') )
+        $found = 1;
+    }
+    elsif( defined($sysDescr) and
+           index( $sysDescr, 'Cisco IOS XR Software' ) >= 0 )
+    {
+        $found = 1;
+        $devdetails->setCap('CiscoIOSXR');
+    }
+    else
+    {
+        # fall back to software image table
+        if( $dd->checkSnmpTable('ciscoImageTable') )
         {
-            # IOS XR has a new MIB for software image management
-            $devdetails->setCap('CiscoIOSXR');            
+            $found = 1;
         }
-        else
+        elsif( $dd->checkSnmpTable('ceImageTable') )
         {
-            return 0;
+            $found = 1;
+            $devdetails->setCap('CiscoIOSXR');
         }
     }
 
+    if( not $found )
+    {
+        return 0;
+    }
+    
     # On some Layer3 switching devices, VlanXXX interfaces give some
     # useful stats, while on others the stats are not relevant at all
     
@@ -228,6 +243,11 @@ sub checkdevtype
 
     $devdetails->setCap('interfaceIndexingManaged');
 
+    if( $devdetails->paramEnabled('CiscoIOS::ifindex-persist') )
+    {
+        $devdetails->setCap('interfaceIndexingPersistent');
+    }
+
     return 1;
 }
 
