@@ -14,7 +14,6 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 
-# $Id$
 # Stanislav Sinyagin <ssinyagin@yahoo.com>
 
 # Cisco VDSL Line statistics.
@@ -23,6 +22,8 @@
 package Torrus::DevDiscover::CiscoVDSL;
 
 use strict;
+use warnings;
+
 use Torrus::Log;
 
 
@@ -109,14 +110,26 @@ sub buildConfig
 
         my $templates = ['CiscoVDSL::cvdsl-interface'];
 
-        my $param = {
-            'interface-name' => $interface->{'param'}{'interface-name'},
-            'interface-nick' => $interface->{'param'}{'interface-nick'},
-            'comment'        => $interface->{'param'}{'comment'}
-        };
+        my $ifParam = {};
 
-        $cb->addSubtree( $subtreeNode, $ifSubtreeName, $param, $templates );
+        $ifParam->{'interface-name'} =
+            $interface->{$data->{'nameref'}{'ifReferenceName'}};
+        $ifParam->{'interface-nick'} =
+            $interface->{$data->{'nameref'}{'ifNick'}};
+        $ifParam->{'node-display-name'} =
+            $interface->{$data->{'nameref'}{'ifReferenceName'}};
+        
+        if( defined($data->{'nameref'}{'ifComment'}) and
+            defined($interface->{$data->{'nameref'}{'ifComment'}}) )
+        {
+            $ifParam->{'comment'} =
+                $interface->{$data->{'nameref'}{'ifComment'}};
+        }
+
+        $cb->addSubtree( $subtreeNode, $ifSubtreeName, $ifParam, $templates );
     }
+
+    return;
 }
 
 
