@@ -14,7 +14,6 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 
-# $Id$
 # Shawn Ferry <sferry at sevenspace dot com> <lalartu at obscure dot org>
 
 # Oracle Database MIB
@@ -22,6 +21,8 @@
 package Torrus::DevDiscover::OracleDatabase;
 
 use strict;
+use warnings;
+
 use Torrus::Log;
 
 
@@ -279,12 +280,13 @@ sub buildConfig
 
         if( $devdetails->hasCap('oraTableSpace') )
         {
-            my $tsParam = {
+            my $subtreeParam = {
                 'comment' => "Table space for $dbName",
                 'precedence' => "600",
             };
 
-            my $tsNode = $cb->addSubtree($dbNode, 'Table_Space', $tsParam );
+            my $tsNode =
+                $cb->addSubtree($dbNode, 'Table_Space', $subtreeParam );
 
             foreach my $tsName ( keys %{ $db->{'oraTableSpace'} } )
             {
@@ -314,12 +316,12 @@ sub buildConfig
 
         if( $devdetails->hasCap('oraDbDataFile') )
         {
-            my $dfParam = {
+            my $subtreeParam = {
                 'comment' => "Data Files for $dbName",
                 'precedence' => "500",
             };
 
-            my $dfNode = $cb->addSubtree($dbNode, 'Data_Files', $dfParam );
+            my $dfNode = $cb->addSubtree($dbNode, 'Data_Files', $subtreeParam );
 
             foreach my $dfName ( keys %{ $db->{'oraDbDataFile'} } )
             {
@@ -350,12 +352,13 @@ sub buildConfig
 
         if( $devdetails->hasCap('oraDbLibraryCache') )
         {
-            my $lcParam = {
+            my $subtreeParam = {
                 'comment' => "Library Cache for $dbName",
                 'precedence' => "400",
             };
 
-            my $lcNode = $cb->addSubtree($dbNode, 'Library_Cache', $lcParam );
+            my $lcNode =
+                $cb->addSubtree($dbNode, 'Library_Cache', $subtreeParam );
 
             foreach my $lcName ( keys %{ $db->{'oraDbLibraryCache'} } )
             {
@@ -382,6 +385,8 @@ sub buildConfig
             }
         }
     }
+
+    return;
 }
 
 
