@@ -14,7 +14,6 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 
-# $Id$
 # Stanislav Sinyagin <ssinyagin@yahoo.com>
 
 # Discovery module for BGP4-MIB (RFC 1657)
@@ -25,6 +24,8 @@
 package Torrus::DevDiscover::RFC1657_BGP4_MIB;
 
 use strict;
+use warnings;
+
 use Torrus::Log;
 
 
@@ -45,29 +46,16 @@ sub discover
     my $data = $devdetails->data();
     my $session = $dd->session();
 
-    my $table = $session->get_table( -baseoid =>
-                                     $dd->oiddef('bgpPeerRemoteAs'));
+    my $table = $dd->walkSnmpTable('bgpPeerRemoteAs');
     
-    if( not defined( $table ) or scalar( %{$table} ) == 0 )
+    if( scalar(keys %{$table}) > 0 )
     {
-        return 0;
-    }
-    
-    $devdetails->storeSnmpVars( $table );
-    $devdetails->setCap('bgpPeerTable');
+        $devdetails->setCap('bgpPeerTable');
 
-
-    foreach my $INDEX
-        ( $devdetails->
-          getSnmpIndices( $dd->oiddef('bgpPeerRemoteAs') ) )
-    {
-        my $ipAddr = $INDEX;
-
-        my $asNum =
-            $devdetails->snmpVar($dd->oiddef('bgpPeerRemoteAs') .
-                                 '.' . $INDEX);
-
-        $data->{'bgpPeerAS'}{$ipAddr} = $asNum;
+        while( my ($ipAddr, $asNum) = each %{$table} )
+        {
+            $data->{'bgpPeerAS'}{$ipAddr} = $asNum;
+        }
     }
                             
     return 1;
