@@ -14,7 +14,6 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 
-# $Id$
 # Shawn Ferry <sferry at sevenspace dot com> <lalartu at obscure dot org>
 # Stanislav Sinyagin <ssinyagin@yahoo.com>
 
@@ -27,6 +26,8 @@
 package Torrus::DevDiscover::RFC2790_HOST_RESOURCES;
 
 use strict;
+use warnings;
+
 use Torrus::Log;
 
 $Torrus::DevDiscover::registry{'RFC2790_HOST_RESOURCES'} = {
@@ -115,8 +116,7 @@ sub discover
     {
         $devdetails->storeSnmpVars( $hrStorageTable );
 
-        my $ref = {};
-        $data->{'hrStorage'} = $ref;
+        $data->{'hrStorage'} = {};
 
         foreach my $INDEX
             ( $devdetails->getSnmpIndices($dd->oiddef('hrStorageIndex') ) )
@@ -194,12 +194,12 @@ sub discover
 
     # hrProcessor support
     {
-        my $oid = $dd->oiddef('hrProcessorLoad');
-        my $table = $session->get_table( -baseoid => $oid );
+        my $base = $dd->oiddef('hrProcessorLoad');
+        my $table = $session->get_table( -baseoid => $base );
         if( defined($table) )
         {
             $data->{'hrProcessors'} = [];
-            my $prefixLen = length( $oid ) + 1;
+            my $prefixLen = length( $base ) + 1;
         
             while( my( $oid, $load ) = each %{$table} )
             {
@@ -227,16 +227,15 @@ sub buildConfig
 
     { # Anon sub for System Performance
         my $subtreeName =
-            $devdetails->param('RFC2790_HOST_RESOURCES::sysperf-subtree-name');
-        if( not defined( $subtreeName ) )
+            $devdetails->paramString
+            ('RFC2790_HOST_RESOURCES::sysperf-subtree-name');
+        if( $subtreeName eq '' )
         {
             $subtreeName = 'System_Performance';
             $devdetails->setParam
                 ('RFC2790_HOST_RESOURCES::sysperf-subtree-name', $subtreeName);
         }
 
-        my $param = {};
-
         my @templates =
             ('RFC2790_HOST_RESOURCES::hr-system-performance-subtree',
              'RFC2790_HOST_RESOURCES::hr-system-uptime');
@@ -251,13 +250,13 @@ sub buildConfig
         }
 
         my $subtreeNode = $cb->addSubtree( $devNode, $subtreeName,
-                                           $param, \@templates );
+                                           {}, \@templates );
 
         if( $devdetails->hasCap('hrProcessor') )
         {
             foreach my $INDEX ( sort {$a<=>$b} @{$data->{'hrProcessors'}} )
             {
-                my $subtreeName = 'CPU_' . $INDEX . '_Load';
+                my $cpuName = 'CPU_' . $INDEX . '_Load';
                 
                 my $param = {
                     'cpu-id' => $INDEX,
@@ -265,7 +264,7 @@ sub buildConfig
                     'precedence' => sprintf("%d", 1000 - $INDEX),
                 };
                 
-                $cb->addLeaf( $subtreeNode, $subtreeName, $param,
+                $cb->addLeaf( $subtreeNode, $cpuName, $param,
                               ['RFC2790_HOST_RESOURCES::hr-processor-load']);
                 
             }
@@ -293,6 +292,8 @@ sub buildConfig
                           $ref->{'param'}, $ref->{'templates'} );
         }
     }
+
+    return;
 }
 
 
