@@ -205,6 +205,8 @@ sub discover
         }
     }
 
+    my $could_not_find_interface_indexing = 0;
+    
     if( not $devdetails->hasCap('interfaceNamingProprietary') )
     {
         ## Set default interface index mapping
@@ -242,7 +244,7 @@ sub discover
         }
         else
         {
-            $devdetails->setCap('interfaceIndexingPersistent');
+            $could_not_find_interface_indexing = 1;
             $data->{'nameref'}{'ifSubtreeName'} = 'ifIndex';
             $data->{'nameref'}{'ifReferenceName'} = 'ifIndex';
             $data->{'nameref'}{'ifNick'} = 'ifIndex';
@@ -294,6 +296,10 @@ sub discover
                       $hint);
             }
         }
+        elsif( $could_not_find_interface_indexing )
+        {
+            $devdetails->setCap('interfaceIndexingPersistent');
+        }
             
         $hint =
             $devdetails->param('RFC2863_IF_MIB::subtree-name-hint');
@@ -302,6 +308,12 @@ sub discover
             if( $hint eq 'ifName' )
             {
                 $data->{'nameref'}{'ifSubtreeName'} = 'ifNameT';
+                $data->{'nameref'}{'ifReferenceName'} = 'ifName';
+            }
+            elsif( $hint eq 'ifDescr' )
+            {
+                $data->{'nameref'}{'ifSubtreeName'} = 'ifDescrT';
+                $data->{'nameref'}{'ifReferenceName'} = 'ifDescr';
             }
             else
             {
@@ -309,7 +321,21 @@ sub discover
                       $hint);
             }
         }
-        
+
+        $hint =
+            $devdetails->param('RFC2863_IF_MIB::name-hint');
+        if( defined( $hint ) )
+        {
+            $data->{'nameref'}{'ifReferenceName'} = $hint;
+        }
+
+        $hint =
+            $devdetails->param('RFC2863_IF_MIB::comment-hint');
+        if( defined( $hint ) )
+        {
+            $data->{'nameref'}{'ifComment'} = $hint;
+        }
+
         $hint =
             $devdetails->param('RFC2863_IF_MIB::nodeid-hint');
         if( defined( $hint ) )
@@ -355,7 +381,8 @@ sub discover
                         $interface->{'ifType'} == $filter->{'ifType'} )
                     {
                         if( not defined( $filter->{'ifDescr'} ) or
-                            $interface->{'ifDescr'} =~ $filter->{'ifDescr'} )
+                            (defined($interface->{'ifDescr'}) and 
+                             $interface->{'ifDescr'} =~ $filter->{'ifDescr'}) )
                         {
                             $match = 1;
                         }
@@ -524,6 +551,21 @@ sub buildConfig
     {
         my $interface = $data->{'interfaces'}{$ifIndex};
 
+        # an interface may be excluded from IF-MIB statistics, but
+        # still use nodeid for other stats
+        
+        if( not defined( $interface->{$data->{'nameref'}{'ifNodeidPrefix'}} ) )
+        {
+            $interface->{$data->{'nameref'}{'ifNodeidPrefix'}} =
+                'if//%nodeid-device%//';
+        }
+        
+        if( not defined( $interface->{$data->{'nameref'}{'ifNodeid'}} ) )
+        {
+            $interface->{$data->{'nameref'}{'ifNodeid'}} =
+                $interface->{$data->{'nameref'}{'ifReferenceName'}};
+        }
+
         next if $interface->{'excluded'};
         $nInterfaces++;
 
@@ -547,18 +589,6 @@ sub buildConfig
                 $interface->{$data->{'nameref'}{'ifVendorSpecific'}};
         }
 
-        if( not defined( $interface->{$data->{'nameref'}{'ifNodeidPrefix'}} ) )
-        {
-            $interface->{$data->{'nameref'}{'ifNodeidPrefix'}} =
-                'if//%nodeid-device%//';
-        }
-        
-        if( not defined( $interface->{$data->{'nameref'}{'ifNodeid'}} ) )
-        {
-            $interface->{$data->{'nameref'}{'ifNodeid'}} =
-                $interface->{$data->{'nameref'}{'ifReferenceName'}};
-        }
-
         # A per-interface value which is used by leafs in IF-MIB templates
         $interface->{'param'}{'nodeid-interface'} =
             $interface->{$data->{'nameref'}{'ifNodeidPrefix'}} .
