@@ -48,19 +48,12 @@ my %mime_type =
 my @arg_arrays = qw(opts defs bg hwtick hrule hwline line fg);
 
 
-sub render_rrgraph
+sub prepare_rrgraph_args
 {
     my $self = shift;
     my $config_tree = shift;
     my $token = shift;
     my $view = shift;
-    my $outfile = shift;
-
-    if( not $config_tree->isLeaf($token) )
-    {
-        Error("Token $token is not a leaf");
-        return undef;
-    }
 
     my $obj = {'args' => {}, 'dname' => 'A'};
 
@@ -167,14 +160,35 @@ sub render_rrgraph
 
     # We're all set
 
-
-    my @args;
+    my $args = [];
     foreach my $arrayName ( @arg_arrays )
     {
-        push( @args, @{$obj->{'args'}{$arrayName}} );
+        push( @{$args}, @{$obj->{'args'}{$arrayName}} );
     }
-    Debug("RRDs::graph arguments: " . join(' ', @args));
 
+    return ($args, $obj);
+}
+
+
+
+sub render_rrgraph
+{
+    my $self = shift;
+    my $config_tree = shift;
+    my $token = shift;
+    my $view = shift;
+    my $outfile = shift;
+
+    if( not $config_tree->isLeaf($token) )
+    {
+        Error("Token $token is not a leaf");
+        return undef;
+    }
+
+    my ($args, $obj) =
+        $self->prepare_rrgraph_args($config_tree, $token, $view);
+    Debug("RRDs::graph arguments: " . join(' ', @{$args}));
+    
     # localize the TZ enviromennt for the child process
     {
         my $tz = $self->{'options'}->{'variables'}->{'TZ'};
@@ -189,7 +203,7 @@ sub render_rrgraph
             $ENV{'TZ'} = $tz;
         }
         
-        &RRDs::graph( $outfile, @args );
+        &RRDs::graph( $outfile, @{$args} );
     }
 
     my $ERR=RRDs::error;
@@ -466,10 +480,12 @@ sub rrd_make_multigraph
                 my $max_dname = $dname . '_Max';
                 
                 my $p_maxlinestyle =
-                    $config_tree->getNodeParam($token, 'maxline-style-'.$dname);
+                    $config_tree->getNodeParam($token,
+                                               'maxline-style-'.$dname);
                 
                 my $p_maxlinecolor =
-                    $config_tree->getNodeParam($token, 'maxline-color-'.$dname);
+                    $config_tree->getNodeParam($token,
+                                               'maxline-color-'.$dname);
 
                 my $step =
                     $self->rrd_maxline_step( $config_tree, $view );
@@ -1050,9 +1066,16 @@ sub rrd_make_def
     }
 
     my $def_options = '';
+    my $step = $config_tree->getNodeParam($token, 'graph-step');
+    
     if( defined($opts) and defined($opts->{'step'}) )
     {
-        $def_options .= ':step=' . $opts->{'step'};
+        $step = $opts->{'step'};
+    }
+
+    if( defined($step) )
+    {
+        $def_options .= ':step=' . $step;
     }
     
     return sprintf( 'DEF:%s=%s:%s:%s%s',
@@ -1079,6 +1102,12 @@ sub rrd_make_cdef
 
     my @args = ();
     my $ok = 1;
+
+    my $step = $config_tree->getNodeParam($token, 'graph-step');
+    if( defined($opts) and defined($opts->{'step'}) )
+    {
+        $step = $opts->{'step'};
+    }
     
     # We will name the DEFs as $dname.sprintf('%.2d', $ds_couter++);
     my $ds_couter = 1;
@@ -1118,9 +1147,9 @@ sub rrd_make_cdef
         }
         else
         {
-            if( defined($opts) and defined($opts->{'step'}) )
+            if( defined($step) )
             {
-                $defstring .= ':step=' . $opts->{'step'};
+                $defstring .= ':step=' . $step;
             }
             push( @args, $defstring );
         }
