@@ -14,7 +14,6 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 
-# $Id$
 # Stanislav Sinyagin <ssinyagin@yahoo.com>
 
 # Package for reports generation
@@ -23,6 +22,8 @@
 package Torrus::ReportGenerator;
 
 use strict;
+use warnings;
+
 use Date::Parse;
 
 use Torrus::Log;
@@ -117,7 +118,7 @@ sub new
 
 sub generate
 {
-    die('Virtual method called');    
+    die('Virtual method Torrus::ReportGenerator::generate() called');    
 }
 
 
