@@ -14,7 +14,6 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 
-# $Id$
 # Stanislav Sinyagin <ssinyagin@yahoo.com>
 
 # For all service IDs available, build monthly usage figures:
@@ -24,15 +23,17 @@
 package Torrus::ReportGenerator::MonthlySrvUsage;
 
 use strict;
+use warnings;
+
+use base 'Torrus::ReportGenerator';
+
 use POSIX qw(floor);
 use Date::Parse;
 use Math::BigFloat;
 
 use Torrus::Log;
-use Torrus::ReportGenerator;
 use Torrus::ServiceID;
 
-use base 'Torrus::ReportGenerator';
 
 sub isMonthly
 {
@@ -207,6 +208,7 @@ sub generate
     &Torrus::DB::checkInterrupted();
 
     $self->{'backend'}->finalize( $self->{'reportId'} );
+    return;
 }
 
 
