@@ -14,7 +14,6 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 
-# $Id$
 # Stanislav Sinyagin <ssinyagin@yahoo.com>
 
 
@@ -22,10 +21,11 @@
 
 package Torrus::SchedulerInfo;
 
+use strict;
+use warnings;
+
 use Torrus::DB;
 use Torrus::Log;
-use strict;
-
 
 sub new
 {
@@ -52,6 +52,7 @@ sub DESTROY
 {
     my $self = shift;
     delete $self->{'db_stats'};
+    return;
 }
 
 
@@ -84,6 +85,7 @@ sub setValue
     my $value = shift;
 
     $self->{'db_stats'}->put( join('#', $id, $variable), $value );
+    return;
 }
 
 sub getValue
@@ -112,6 +114,7 @@ sub clearStats
         }
     }
     $self->{'db_stats'}->c_close($cursor);
+    return;
 }
 
 
@@ -119,6 +122,7 @@ sub clearAll
 {
     my $self = shift;
     $self->{'db_stats'}->trunc();
+    return;
 }
 
 
@@ -178,6 +182,7 @@ sub setStatsValues
         $expAverage = $alpha * $value + ( 1 - $alpha ) * $expAverage;
     }
     $self->setValue( $id, $expAvgName, $expAverage );
+    return;
 }
 
 
@@ -202,6 +207,7 @@ sub incStatsCounter
     }
     
     $self->setValue( $id, $name, $previous + $increment );
+    return;
 }
 
 
