@@ -14,15 +14,16 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 
-# $Id$
 # Stanislav Sinyagin <ssinyagin@yahoo.com>
 
 ## %Torrus::Global::treeConfig manipulation
 
 package Torrus::SiteConfig;
 
-use Torrus::Log;
 use strict;
+use warnings;
+
+use Torrus::Log;
 
 our %validDaemonNames = ('collector' => 1,
                          'monitor'   => 1);
@@ -322,6 +323,7 @@ sub loadStyling
     {
         require $Torrus::Renderer::stylingProfileOverlay;
     }
+    return;
 }
 
 
