@@ -14,15 +14,16 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 
-# $Id$
 # Stanislav Sinyagin <ssinyagin@yahoo.com>
 
 package Torrus::TimeStamp;
 
+use strict;
+use warnings;
+
 use Torrus::DB;
 use Torrus::Log;
 
-use strict;
 
 $Torrus::TimeStamp::db = undef;
 
@@ -36,11 +37,13 @@ sub init
     not defined( $Torrus::TimeStamp::db ) or
         die('$Torrus::TimeStamp::db is defined at init');
     $Torrus::TimeStamp::db = new Torrus::DB('timestamps', -WriteAccess => 1);
+    return;
 }
 
 sub release
 {
     undef $Torrus::TimeStamp::db;
+    return;
 }
 
 sub setNow
@@ -49,6 +52,7 @@ sub setNow
     ref( $Torrus::TimeStamp::db ) or
         die('$Torrus::TimeStamp::db is not defined at setNow');
     $Torrus::TimeStamp::db->put( $tname, time() );
+    return;
 }
 
 sub get
