@@ -3,7 +3,6 @@
 # with $Torrus::Renderer::stylingProfile in your torrus-siteconfig.pl
 # or better define your amendments in Torrus::Renderer::stylingProfileOverlay
 
-# $Id$
 # Stanislav Sinyagin <ssinyagin@yahoo.com>
 # Shawn Ferry <sferry at sevenspace dot com> <lalartu at obscure dot org>
 
@@ -12,6 +11,10 @@
      'SingleGraph'     => {
          'color' => '##blue',
          'line'  => 'LINE2'
+         },     
+     'SingleGraphMax'  => {  # MAX value graph on top of the Average
+         'color' => '##cornflowerblue',
+         'line'  => 'LINE1'
          },
      'HWBoundary'     => {
          'color' => '##red',
@@ -30,13 +33,21 @@
          'color' => '##darkmagenta'
          },
      'BpsIn'          => {
-         'color' => '##green',
+         'color' => '#01ca00',
          'line'  => 'AREA'
          },
      'BpsOut'         => {
          'color' => '##blue',
          'line'  => 'LINE2'
          },
+     'BpsInMax'          => {
+         'color' => '#b7ea8c',
+         'line'  => 'AREA'
+         },
+     'BpsOutMax'         => {
+         'color' => '#017eb5',
+         'line'  => 'LINE1'
+         },
 
      'BusinessDay'    => {
          'color' => '##white',
@@ -107,6 +118,25 @@
      'nine'     => {'color'   => '##darkmagenta'},
      'ten'      => {'color'   => '##orangered'},
 
+     # Numbered palette to make dynamically assembled stacked charts
+     # dark28 and accent8 color schemes, from
+     # http://bloodgate.com/perl/graph/manual/att_colors.html
+     'clr1'     => {'color'   => '#1b9e77'},
+     'clr2'     => {'color'   => '#d95f02'},
+     'clr3'     => {'color'   => '#7570b3'},
+     'clr4'     => {'color'   => '#e7298a'},
+     'clr5'     => {'color'   => '#66a61e'},
+     'clr6'     => {'color'   => '#e6ab02'},
+     'clr7'     => {'color'   => '#a6761d'},
+     'clr8'     => {'color'   => '#666666'},
+     'clr9'     => {'color'   => '#7fc97f'},
+     'clr10'    => {'color'   => '#beaed4'},
+     'clr11'    => {'color'   => '#fdc086'},
+     'clr12'    => {'color'   => '#ffd92f'},
+     'clr13'    => {'color'   => '#386cb0'},
+     'clr14'    => {'color'   => '#f0027f'},
+     'clr15'    => {'color'   => '#bf5b17'},
+     
      # definitions for combinatorial graphing
 
      #RED
